# Generated by roxygen2: do not edit by hand

S3method(AIC,scf_model_result)
S3method(SE,scf_MIresult)
S3method(coef,scf_MIresult)
S3method(coef,scf_model_result)
S3method(formula,scf_model_result)
S3method(predict,scf_model_result)
S3method(print,scf_corr)
S3method(print,scf_freq)
S3method(print,scf_glm)
S3method(print,scf_logit)
S3method(print,scf_mean)
S3method(print,scf_median)
S3method(print,scf_mi_survey)
S3method(print,scf_ols)
S3method(print,scf_percentile)
S3method(print,scf_prop_test)
S3method(print,scf_quantreg)
S3method(print,scf_ttest)
S3method(print,scf_xtab)
S3method(residuals,scf_model_result)
S3method(scf_deflate,default)
S3method(scf_deflate,scf_mean)
S3method(scf_deflate,scf_median)
S3method(scf_deflate,scf_percentile)
S3method(scf_deflate,scf_ttest)
S3method(summary,scf_corr)
S3method(summary,scf_freq)
S3method(summary,scf_glm)
S3method(summary,scf_logit)
S3method(summary,scf_mean)
S3method(summary,scf_median)
S3method(summary,scf_ols)
S3method(summary,scf_percentile)
S3method(summary,scf_quantreg)
S3method(summary,scf_ttest)
S3method(summary,scf_xtab)
S3method(vcov,scf_MIresult)
S3method(vcov,scf_model_result)
export(SE)
export(scf_MIcombine)
export(scf_activate_theme)
export(scf_corr)
export(scf_deflate)
export(scf_design)
export(scf_download)
export(scf_freq)
export(scf_glm)
export(scf_implicates)
export(scf_load)
export(scf_logit)
export(scf_mean)
export(scf_median)
export(scf_ols)
export(scf_pctile_cut)
export(scf_pctile_sum)
export(scf_percentile)
export(scf_plot_bbar)
export(scf_plot_cbar)
export(scf_plot_dbar)
export(scf_plot_dist)
export(scf_plot_hex)
export(scf_plot_hist)
export(scf_plot_smooth)
export(scf_prop_test)
export(scf_quantreg)
export(scf_regtable)
export(scf_subset)
export(scf_theme)
export(scf_ttest)
export(scf_update)
export(scf_update_by_implicate)
export(scf_xtab)
import(ggplot2)
importFrom(rlang,.data)
importFrom(stats,AIC)
importFrom(stats,IQR)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,ave)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,deviance)
importFrom(stats,family)
importFrom(stats,formula)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(stats,weighted.mean)
importFrom(stats,weights)
importFrom(stats,xtabs)
importFrom(survey,SE)
importFrom(survey,cv)
importFrom(survey,withReplicates)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(utils,unzip)
importFrom(utils,write.csv)
