# zzz.R

# Register global variables to silence CMD check notes
utils::globalVariables(c(
  "group", "category", "estimate", "yval", "xval", "wgt", "x",
  "percent", "proportion", "imp", "weights"
))

